@@ -1,33 +1,33 @@
 /*
-   Copyright (C) CFEngine AS
+  Copyright 2024 Northern.tech AS
 
-   This file is part of CFEngine 3 - written and maintained by CFEngine AS.
+  This file is part of CFEngine 3 - written and maintained by Northern.tech AS.
 
-   This program is free software; you can redistribute it and/or modify it
-   under the terms of the GNU General Public License as published by the
-   Free Software Foundation; version 3.
+  This program is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by the
+  Free Software Foundation; version 3.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 
   To the extent this program is licensed as part of the Enterprise
-  versions of CFEngine, the applicable Commerical Open Source License
+  versions of CFEngine, the applicable Commercial Open Source License
   (COSL) may apply to this file if you as a licensee so wish it. See
   included file COSL.txt.
 */
 
-#include "platform.h"
+#include <platform.h>
 
-#include "cf3.defs.h"
-#include "bool.h"
-#include "logic_expressions.h"
-#include "misc_lib.h"
+#include <cf3.defs.h>
+#include <stdbool.h>
+#include <logic_expressions.h>
+#include <misc_lib.h>
 
 #include <stdlib.h>
 
@@ -66,7 +66,7 @@ static ParseResult ParsePrimary(const char *expr, int start, int end)
         {
             Expression *res = xcalloc(1, sizeof(Expression));
 
-            res->op = EVAL;
+            res->op = LOGICAL_OP_EVAL;
             res->val.eval.name = strres.result;
 
             return (ParseResult) {res, strres.position};
@@ -90,7 +90,7 @@ static ParseResult ParseNotExpression(const char *expr, int start, int end)
         {
             Expression *res = xcalloc(1, sizeof(Expression));
 
-            res->op = NOT;
+            res->op = LOGICAL_OP_NOT;
             res->val.not.arg = primres.result;
 
             return (ParseResult) {res, primres.position};
@@ -134,7 +134,7 @@ static ParseResult ParseAndExpression(const char *expr, int start, int end)
     }
 
     res = xcalloc(1, sizeof(Expression));
-    res->op = AND;
+    res->op = LOGICAL_OP_AND;
     res->val.andor.lhs = lhs.result;
     res->val.andor.rhs = rhs.result;
 
@@ -180,7 +180,7 @@ ParseResult ParseExpression(const char *expr, int start, int end)
     }
 
     res = xcalloc(1, sizeof(Expression));
-    res->op = OR;
+    res->op = LOGICAL_OP_OR;
     res->val.andor.lhs = lhs.result;
     res->val.andor.rhs = rhs.result;
 
@@ -194,44 +194,44 @@ ExpressionValue EvalExpression(const Expression *expr,
 {
     switch (expr->op)
     {
-    case OR:
-    case AND:
+    case LOGICAL_OP_OR:
+    case LOGICAL_OP_AND:
     {
-        ExpressionValue lhs = EXP_ERROR, rhs = EXP_ERROR;
+        ExpressionValue lhs = EXPRESSION_VALUE_ERROR, rhs = EXPRESSION_VALUE_ERROR;
 
         lhs = EvalExpression(expr->val.andor.lhs, nameevalfn, varrefevalfn, param);
-        if (lhs == EXP_ERROR)
+        if (lhs == EXPRESSION_VALUE_ERROR)
         {
-            return EXP_ERROR;
+            return EXPRESSION_VALUE_ERROR;
         }
 
         rhs = EvalExpression(expr->val.andor.rhs, nameevalfn, varrefevalfn, param);
 
-        if (rhs == EXP_ERROR)
+        if (rhs == EXPRESSION_VALUE_ERROR)
         {
-            return EXP_ERROR;
+            return EXPRESSION_VALUE_ERROR;
         }
 
-        if (expr->op == OR)
+        if (expr->op == LOGICAL_OP_OR)
         {
-            return lhs || rhs;
+            return ((ExpressionValue) (lhs || rhs));
         }
         else
         {
-            return lhs && rhs;
+            return ((ExpressionValue) (lhs && rhs));
         }
     }
 
-    case NOT:
+    case LOGICAL_OP_NOT:
     {
         ExpressionValue arg = EvalExpression(expr->val.not.arg,
                                              nameevalfn,
                                              varrefevalfn,
                                              param);
 
-        if (arg == EXP_ERROR)
+        if (arg == EXPRESSION_VALUE_ERROR)
         {
-            return EXP_ERROR;
+            return EXPRESSION_VALUE_ERROR;
         }
         else
         {
@@ -239,19 +239,30 @@ ExpressionValue EvalExpression(const Expression *expr,
         }
     }
 
-    case EVAL:
+    case LOGICAL_OP_EVAL:
     {
-        ExpressionValue ret = EXP_ERROR;
+        ExpressionValue ret = EXPRESSION_VALUE_ERROR;
         char *name = EvalStringExpression(expr->val.eval.name,
                                           varrefevalfn,
                                           param);
 
         if (name == NULL)
         {
-            return EXP_ERROR;
+            return EXPRESSION_VALUE_ERROR;
+        }
+        else if (strcmp("true", name) == 0)
+        {
+            ret =  EXPRESSION_VALUE_TRUE;
+        }
+        else if (strcmp("false", name) == 0)
+        {
+            ret =  EXPRESSION_VALUE_FALSE;
+        }
+        else
+        {
+            ret = (*nameevalfn) (name, param);
         }
 
-        ret = (*nameevalfn) (name, param);
         free(name);
         return ret;
     }
@@ -272,15 +283,15 @@ void FreeExpression(Expression *e)
 
     switch (e->op)
     {
-    case OR:
-    case AND:
+    case LOGICAL_OP_OR:
+    case LOGICAL_OP_AND:
         FreeExpression(e->val.andor.lhs);
         FreeExpression(e->val.andor.rhs);
         break;
-    case NOT:
+    case LOGICAL_OP_NOT:
         FreeExpression(e->val.not.arg);
         break;
-    case EVAL:
+    case LOGICAL_OP_EVAL:
         FreeStringExpression(e->val.eval.name);
         break;
     default:
